You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2011/03/01 21:10:21 UTC

svn commit: r1076012 - /subversion/branches/1.6.x/STATUS

Author: stsp
Date: Tue Mar  1 20:10:21 2011
New Revision: 1076012

URL: http://svn.apache.org/viewvc?rev=1076012&view=rev
Log:
* STATUS: Amend the 1.6.x-issue3719 branch entry again.

Modified:
    subversion/branches/1.6.x/STATUS

Modified: subversion/branches/1.6.x/STATUS
URL: http://svn.apache.org/viewvc/subversion/branches/1.6.x/STATUS?rev=1076012&r1=1076011&r2=1076012&view=diff
==============================================================================
--- subversion/branches/1.6.x/STATUS (original)
+++ subversion/branches/1.6.x/STATUS Tue Mar  1 20:10:21 2011
@@ -223,8 +223,8 @@ Candidate changes:
     Justification:
       Has been reported to improve checkout performance on Windows
       by a factor of 10 for one user (85 minutes down to 8 minutes).
-      The problem is most visible in working copies that have many
-      files in a single directory.
+      The problem is most visible on NTFS with working copies that have
+      many files with svn: properties.
     Notes:
       See the issue for details, and also this thread:
       http://svn.haxx.se/dev/archive-2011-02/0066.shtml